==> openGion6.4.0.4_src.zip: gf/src/org/opengion/hayabusa/taglib/ViewITableTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.fukurou.util.TagBuffer;
import org.opengion.fukurou.util.ToString;						// 6.1.1.0 (2015/01/17)

import static org.opengion.fukurou.util.StringUtil.nval ;		// 6.1.0.0 (2014/12/26)

/**
 * JavaScriptを利用してクライアント側でテーブルの左右分割します。
 *
 * iTable タグは、ガント全体の左右２分割表示したいカラム数を、fixedCols 属性に指定します。
 * 通常の view タグの後に記述します。
 *
 * @og.formSample
 * ●形式：&lt;og:iTable  ... /&gt;
 * ●body：なし
 * ●前提：headタグで、adjustEvent="Table" を指定してください。
 *
 * ●Tag定義：
 *   &lt;og:iTable
 *       fixedCols        ○【TAG】左右２分割で、固定したいカラム数(必須)
 *       debug              【TAG】デバッグ情報を出力するかどうか[true/false]を指定します(初期値:false)
 *   /&gt;
 *
 * ●使用例
 *  &lt;og:view
 *      viewFormType = "HTMLTable"
 *      command      = "{&#064;command}"
 *  /&gt;

 *   &lt;og:iTable
 *       fixedCols  = "5"
 *   /&gt;
 *
 * @og.rev 5.6.3.2 (2013/04/12) 新規作成
 * @og.group 画面部品
 *
 * @version  5.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK6.0,
 */
public class ViewITableTag extends CommonTagSupport {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.0.2.5 (2014/10/31)" ;

	private static final long serialVersionUID = 602520141031L ;

	private transient TagBuffer tag = new TagBuffer( "iTable" ).addBody( "<!-- -->" );		// 6.1.1.0 (2015/01/17) TagBufferの連結記述

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @og.rev 6.0.2.5 (2014/10/31) HTML5対応。javaScriptで、BODYがないと入れ子になってしまう。
	 *
	 * @return	後続処理の指示
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)

		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
		jspPrint( tag.makeTag() );

		return EVAL_PAGE ;		// ページの残りを評価する。
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 */
	@Override
	protected void release2() {
		super.release2();
		tag = new TagBuffer( "iTable" ).addBody( "<!-- -->" );		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
	}

	/**
	 * 【TAG】左右２分割で、固定したいカラム数を指定します。
	 *
	 * @og.tag
	 * １段組でも２段組でも、固定したいカラム数を指定します。
	 *
	 * @param   fixedCols 固定したいカラム数
	 */
	public void setFixedCols( final String fixedCols ) {
		tag.add( "fixedCols",nval( getRequestParameter( fixedCols ),null ) );
	}

	/**
	 * タグの名称を、返します。
	 * 自分自身のクラス名より、自動的に取り出せないため、このメソッドをオーバーライドします。
	 *
	 * @return  タグの名称
	 * @og.rtnNotNull
	 */
	@Override
	protected String getTagName() {
		return "iTable" ;
	}

	/**
	 * このオブジェクトの文字列表現を返します。
	 * 基本的にデバッグ目的に使用します。
	 *
	 * @return このクラスの文字列表現
	 * @og.rtnNotNull
	 */
	@Override
	public String toString() {
		return ToString.title( this.getClass().getName() )
				.println( "VERSION"		,VERSION	)
				.println( "tag"			,tag.makeTag()	)
				.println( "Other..."	,getAttributes().getAttribute() )
				.fixForm().toString() ;
	}
}

==> openGion6.4.5.3_src.zip: gf/src/org/opengion/hayabusa/taglib/ViewITableTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.fukurou.util.TagBuffer;
import org.opengion.fukurou.util.ToString;						// 6.1.1.0 (2015/01/17)

import static org.opengion.fukurou.util.StringUtil.nval ;		// 6.1.0.0 (2014/12/26)

/**
 * JavaScriptを利用してクライアント側でテーブルの左右分割します。
 *
 * iTable タグは、ガント全体の左右２分割表示したいカラム数を、fixedCols 属性に指定します。
 * 通常の view タグの後に記述します。
 *
 * @og.formSample
 * ●形式：&lt;og:iTable  ... /&gt;
 * ●body：なし
 * ●前提：headタグで、adjustEvent="Table" を指定してください。
 *
 * ●Tag定義：
 *   &lt;og:iTable
 *       fixedCols        ○【TAG】左右２分割で、固定したいカラム数(必須)
 *       debug              【TAG】デバッグ情報を出力するかどうか[true/false]を指定します(初期値:false)
 *   /&gt;
 *
 * ●使用例
 *  &lt;og:view
 *      viewFormType = "HTMLTable"
 *      command      = "{&#064;command}"
 *  /&gt;

 *   &lt;og:iTable
 *       fixedCols  = "5"
 *   /&gt;
 *
 * @og.rev 5.6.3.2 (2013/04/12) 新規作成
 * @og.group 画面部品
 *
 * @version  5.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK6.0,
 */
public class ViewITableTag extends CommonTagSupport {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.4.2.0 (2016/01/29)" ;
	private static final long serialVersionUID = 642020160129L ;

	private transient TagBuffer tag = new TagBuffer( "iTable" ).addBody( "<!-- -->" );		// 6.1.1.0 (2015/01/17) TagBufferの連結記述

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public ViewITableTag() {
		super();		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。
	}

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @og.rev 6.0.2.5 (2014/10/31) HTML5対応。javaScriptで、BODYがないと入れ子になってしまう。
	 *
	 * @return	後続処理の指示
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)

		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
		jspPrint( tag.makeTag() );

		return EVAL_PAGE ;		// ページの残りを評価する。
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 */
	@Override
	protected void release2() {
		super.release2();
		tag = new TagBuffer( "iTable" ).addBody( "<!-- -->" );		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
	}

	/**
	 * 【TAG】左右２分割で、固定したいカラム数を指定します。
	 *
	 * @og.tag
	 * １段組でも２段組でも、固定したいカラム数を指定します。
	 *
	 * @param   fixedCols 固定したいカラム数
	 */
	public void setFixedCols( final String fixedCols ) {
		tag.add( "fixedCols",nval( getRequestParameter( fixedCols ),null ) );
	}

	/**
	 * タグの名称を、返します。
	 * 自分自身のクラス名より、自動的に取り出せないため、このメソッドをオーバーライドします。
	 *
	 * @return  タグの名称
	 * @og.rtnNotNull
	 */
	@Override
	protected String getTagName() {
		return "iTable" ;
	}

	/**
	 * このオブジェクトの文字列表現を返します。
	 * 基本的にデバッグ目的に使用します。
	 *
	 * @return このクラスの文字列表現
	 * @og.rtnNotNull
	 */
	@Override
	public String toString() {
		return ToString.title( this.getClass().getName() )
				.println( "VERSION"		,VERSION	)
				.println( "tag"			,tag.makeTag()	)
				.println( "Other..."	,getAttributes().getAttribute() )
				.fixForm().toString() ;
	}
}
